==> open-xchange-server_6.10.0.0.orig.tar.gz: open-xchange-server-6.10.0.0/src/com/openexchange/userconf/internal/UserConfigurationServiceImpl.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2006 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.userconf.internal;

import com.openexchange.groupware.contexts.Context;
import com.openexchange.groupware.userconfiguration.UserConfiguration;
import com.openexchange.groupware.userconfiguration.UserConfigurationException;
import com.openexchange.groupware.userconfiguration.UserConfigurationStorage;
import com.openexchange.userconf.UserConfigurationService;

/**
 * {@link UserConfigurationServiceImpl}
 * 
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class UserConfigurationServiceImpl implements UserConfigurationService {

    /**
     * Initializes a new {@link UserConfigurationServiceImpl}.
     */
    public UserConfigurationServiceImpl() {
        super();
    }

    public void clearStorage() throws UserConfigurationException {
        UserConfigurationStorage.getInstance().clearStorage();
    }

    public UserConfiguration getUserConfiguration(final int userId, final Context ctx) throws UserConfigurationException {
        return UserConfigurationStorage.getInstance().getUserConfiguration(userId, ctx);
    }

    public UserConfiguration getUserConfiguration(final int userId, final int[] groups, final Context ctx) throws UserConfigurationException {
        return UserConfigurationStorage.getInstance().getUserConfiguration(userId, groups, ctx);
    }

    public void removeUserConfiguration(final int userId, final Context ctx) throws UserConfigurationException {
        UserConfigurationStorage.getInstance().removeUserConfiguration(userId, ctx);
    }

    public void saveUserConfiguration(final UserConfiguration userConfiguration) throws UserConfigurationException {
        UserConfigurationStorage.getInstance().saveUserConfiguration(userConfiguration);
    }

    public void saveUserConfiguration(final int permissionBits, final int userId, final Context ctx) throws UserConfigurationException {
        UserConfigurationStorage.getInstance().saveUserConfiguration(permissionBits, userId, ctx);
    }

    public UserConfiguration getUserConfigurationSafe(final int userId, final Context ctx) {
        return UserConfigurationStorage.getInstance().getUserConfigurationSafe(userId, ctx);
    }

    public UserConfiguration getUserConfigurationSafe(final int userId, final int[] groups, final Context ctx) {
        return UserConfigurationStorage.getInstance().getUserConfigurationSafe(userId, groups, ctx);
    }

}

==> open-xchange-server_6.12.0.0.orig.tar.gz: open-xchange-server-6.12.0.0/src/com/openexchange/userconf/internal/UserConfigurationServiceImpl.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2006 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.userconf.internal;

import com.openexchange.groupware.contexts.Context;
import com.openexchange.groupware.ldap.User;
import com.openexchange.groupware.userconfiguration.UserConfiguration;
import com.openexchange.groupware.userconfiguration.UserConfigurationException;
import com.openexchange.groupware.userconfiguration.UserConfigurationStorage;
import com.openexchange.userconf.UserConfigurationService;

/**
 * {@link UserConfigurationServiceImpl}
 * 
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class UserConfigurationServiceImpl implements UserConfigurationService {

    /**
     * Initializes a new {@link UserConfigurationServiceImpl}.
     */
    public UserConfigurationServiceImpl() {
        super();
    }

    public void clearStorage() throws UserConfigurationException {
        UserConfigurationStorage.getInstance().clearStorage();
    }

    public UserConfiguration getUserConfiguration(final int userId, final Context ctx) throws UserConfigurationException {
        return UserConfigurationStorage.getInstance().getUserConfiguration(userId, ctx);
    }

    public UserConfiguration getUserConfiguration(final int userId, final int[] groups, final Context ctx) throws UserConfigurationException {
        return UserConfigurationStorage.getInstance().getUserConfiguration(userId, groups, ctx);
    }

    public UserConfiguration[] getUserConfiguration(Context ctx, User[] users) throws UserConfigurationException {
        return UserConfigurationStorage.getInstance().getUserConfiguration(ctx, users);
    }

    public void removeUserConfiguration(final int userId, final Context ctx) throws UserConfigurationException {
        UserConfigurationStorage.getInstance().removeUserConfiguration(userId, ctx);
    }

    public void saveUserConfiguration(final UserConfiguration userConfiguration) throws UserConfigurationException {
        UserConfigurationStorage.getInstance().saveUserConfiguration(userConfiguration);
    }

    public void saveUserConfiguration(final int permissionBits, final int userId, final Context ctx) throws UserConfigurationException {
        UserConfigurationStorage.getInstance().saveUserConfiguration(permissionBits, userId, ctx);
    }

    public UserConfiguration getUserConfigurationSafe(final int userId, final Context ctx) {
        return UserConfigurationStorage.getInstance().getUserConfigurationSafe(userId, ctx);
    }

    public UserConfiguration getUserConfigurationSafe(final int userId, final int[] groups, final Context ctx) {
        return UserConfigurationStorage.getInstance().getUserConfigurationSafe(userId, groups, ctx);
    }

}
